@@ -15,11 +15,11 @@ use App::DBBrowser::DB_Credentials;
 
 
 sub new {
-    my ( $class, $opt ) = @_;
-    $opt->{db_driver} = 'Pg';
-    $opt->{driver_prefix} = 'pg';
-    $opt->{plugin_api_version} = 1.4;
-    bless $opt, $class;
+    my ( $class, $ref ) = @_;
+    $ref->{db_driver} = 'Pg';
+    $ref->{driver_prefix} = 'pg';
+    $ref->{plugin_api_version} = 1.5;
+    bless $ref, $class;
 }
 
 
@@ -168,6 +168,11 @@ sub get_table_names {
 }
 
 
+sub primary_key_auto {
+    return "SERIAL PRIMARY KEY";
+}
+
+
 sub column_names_and_types {
     my ( $self, $dbh, $db, $schema, $tables ) = @_;
     my ( $col_names, $col_types );
